@@ -37,7 +37,6 @@
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
 
-#include "gdl-tools.h"
 #include "gdl-dock.h"
 #include "gdl-dock-item.h"
 #include "gdl-dock-item-grip.h"
@@ -54,7 +53,6 @@
 /* ----- Private prototypes ----- */
 
 static void  gdl_dock_item_class_init    (GdlDockItemClass *class);
-static void  gdl_dock_item_instance_init (GdlDockItem *item);
 
 static GObject *gdl_dock_item_constructor (GType                  type,
                                            guint                  n_construct_properties,
@@ -193,7 +191,7 @@ struct _GdlDockItemPrivate {
 
 /* ----- Private functions ----- */
 
-GDL_CLASS_BOILERPLATE (GdlDockItem, gdl_dock_item, GdlDockObject, GDL_TYPE_DOCK_OBJECT);
+G_DEFINE_TYPE (GdlDockItem, gdl_dock_item, GDL_TYPE_DOCK_OBJECT);
 
 static void
 gdl_dock_item_class_init (GdlDockItemClass *klass)
@@ -404,7 +402,7 @@ gdl_dock_item_class_init (GdlDockItemClass *klass)
 }
 
 static void
-gdl_dock_item_instance_init (GdlDockItem *item)
+gdl_dock_item_init (GdlDockItem *item)
 {
     gtk_widget_set_has_window (GTK_WIDGET (item), TRUE);
 
@@ -456,12 +454,9 @@ gdl_dock_item_constructor (GType                  type,
 {
     GObject *g_object;
     
-    g_object = GDL_CALL_PARENT_WITH_DEFAULT (G_OBJECT_CLASS, 
-                                               constructor, 
-                                               (type,
-                                                n_construct_properties,
-                                                construct_param),
-                                               NULL);
+    g_object = G_OBJECT_CLASS (gdl_dock_item_parent_class)-> constructor (type,
+                                                                     n_construct_properties,
+                                                                     construct_param);
     if (g_object) {
         GdlDockItem *item = GDL_DOCK_ITEM (g_object);
         GtkWidget *hbox;
@@ -633,7 +628,7 @@ gdl_dock_item_destroy (GtkObject *object)
         g_free (priv);
     }
 
-    GDL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+    GTK_OBJECT_CLASS (gdl_dock_item_parent_class)->destroy (object);
 }
 
 static void 
@@ -786,7 +781,7 @@ gdl_dock_item_size_request (GtkWidget      *widget,
     requisition->width += (border_width + style->xthickness) * 2;
     requisition->height += (border_width + style->ythickness) * 2;
 
-    widget->requisition = *requisition;
+    //gtk_widget_size_request (widget, requisition);    
 }
 
 static void
@@ -994,9 +989,10 @@ gdl_dock_item_expose (GtkWidget      *widget,
     g_return_val_if_fail (event != NULL, FALSE);
 
     if (gtk_widget_is_drawable (widget) &&
-        event->window == gtk_widget_get_window (widget)) {
+        event->window == gtk_widget_get_window (widget)) 
+    {
         gdl_dock_item_paint (widget, event);
-        GDL_CALL_PARENT_GBOOLEAN(GTK_WIDGET_CLASS, expose_event, (widget,event));
+        GTK_WIDGET_CLASS (gdl_dock_item_parent_class)->expose_event (widget,event);
     }
   
     return FALSE;
@@ -1152,10 +1148,7 @@ gdl_dock_item_key_press (GtkWidget   *widget,
     if (event_handled)
         return TRUE;
     else
-        return GDL_CALL_PARENT_WITH_DEFAULT (GTK_WIDGET_CLASS,
-                                               key_press_event,
-                                               (widget, event),
-                                               FALSE);
+        return GTK_WIDGET_CLASS (gdl_dock_item_parent_class)->key_press_event (widget, event);
 }
 
 static gboolean
@@ -1164,21 +1157,21 @@ gdl_dock_item_dock_request (GdlDockObject  *object,
                             gint            y,
                             GdlDockRequest *request)
 {
-    GtkAllocation *alloc;
+    GtkAllocation  alloc;
     gint           rel_x, rel_y;
 
     /* we get (x,y) in our allocation coordinates system */
     
     /* Get item's allocation. */
-    gtk_widget_get_allocation (GTK_WIDGET (object), alloc);
+    gtk_widget_get_allocation (GTK_WIDGET (object), &alloc);
     
     /* Get coordinates relative to our window. */
-    rel_x = x - alloc->x;
-    rel_y = y - alloc->y;
+    rel_x = x - alloc.x;
+    rel_y = y - alloc.y;
 
     /* Location is inside. */
-    if (rel_x > 0 && rel_x < alloc->width &&
-        rel_y > 0 && rel_y < alloc->height) {
+    if (rel_x > 0 && rel_x < alloc.width &&
+        rel_y > 0 && rel_y < alloc.height) {
         float rx, ry;
         GtkRequisition my, other;
         gint divider = -1;
@@ -1188,8 +1181,8 @@ gdl_dock_item_dock_request (GdlDockObject  *object,
         gdl_dock_item_preferred_size (GDL_DOCK_ITEM (object), &my);
         
         /* Calculate location in terms of the available space (0-100%). */
-        rx = (float) rel_x / alloc->width;
-        ry = (float) rel_y / alloc->height;
+        rx = (float) rel_x / alloc.width;
+        ry = (float) rel_y / alloc.height;
 
         /* Determine dock location. */
         if (rx < SPLIT_RATIO) {
@@ -1215,8 +1208,8 @@ gdl_dock_item_dock_request (GdlDockObject  *object,
         /* Reset rectangle coordinates to entire item. */
         request->rect.x = 0;
         request->rect.y = 0;
-        request->rect.width = alloc->width;
-        request->rect.height = alloc->height;
+        request->rect.width = alloc.width;
+        request->rect.height = alloc.height;
 
         /* Calculate docking indicator rectangle size for new locations. Only
            do this when we're not over the item's current location. */
@@ -1251,8 +1244,8 @@ gdl_dock_item_dock_request (GdlDockObject  *object,
 
         /* adjust returned coordinates so they are have the same
            origin as our window */
-        request->rect.x += alloc->x;
-        request->rect.y += alloc->y;
+        request->rect.x += alloc.x;
+        request->rect.y += alloc.y;
         
         /* Set possible target location and return TRUE. */            
         request->target = object;
@@ -1820,8 +1813,8 @@ gdl_dock_item_set_orientation (GdlDockItem    *item,
                               "orientation", orientation,
                               NULL);
         };
-
-        GDL_CALL_VIRTUAL (item, GDL_DOCK_ITEM_GET_CLASS, set_orientation, (item, orientation));
+        if (GDL_DOCK_ITEM_GET_CLASS (item)->set_orientation)
+            GDL_DOCK_ITEM_GET_CLASS (item)->set_orientation (item, orientation);
         g_object_notify (G_OBJECT (item), "orientation");
     }
 }
